# PyDClass
###  PyDClass is a simple Python class diagram generator.

PyDClass generate a simple svg image and start a web server for host this image.

### How to install?
It's verry simple! You can run:
```bash
pip install git+https://github.com/CeltiumCDev/PyDClass
```
 ** ⚠️ Warning! If you have not got git installed, you can install it or use this command: **
```bash
pip install pydclass
```
-> Using this syntax is certainly easier but is not recommended if you can do the same thing with this one above because we update GitHub more often than PyPi.

### How to use?
It's also verry simple!

You must go into your project directory and run
```bash
pydclass # The application will be load every python file into the directory and show every class in there.
```
A web server will be started on the port "8080", you can go here!

## FAQ

* **Why inherited attributes appear and not inherited methods?** Why not? No I'm kidding! We are in the process of fixing this.
* **Is there Windows or Mac support?** Yes for Mac, not for Windows.
* **Is the program compatible with Python2?** Maybe, but it's not designed for that.

Post your questions on Discord ( ** Comming soon... ** )

Thanks you for reading!


